package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.vehicle.api.dto.NewInformDTO;
import com.chelvc.cloud.vehicle.api.dto.OmsOrderOperateHistoryDTO;
import com.chelvc.cloud.vehicle.api.service.InformService;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.common.model.Paging;
import lombok.RequiredArgsConstructor;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * 订单通知接口
 *
 * @author igl
 * @Date 2023/12/13
 **/
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping
public class InformController {

    @DubboReference
    private final InformService informService;


    /**
     * 获取用户的订单列表
     *
     * @param paging 分页信息
     * @return 用户的订单列表
     */
    @GetMapping("/order/inform")
    public Pagination<OmsOrderOperateHistoryDTO> listUserOrderInform(@Valid Paging paging) {
        return informService.selectOmsOrderOperateHistoryListByUserId(SessionContextHolder.getId(), paging);
    }

    /**
     * 将新订单通知标识更改
     *
     */
    @PutMapping("/order/inform/flag")
    public void changeUserOrderInformFlag() {
        informService.changeUserOrderInformFlag(SessionContextHolder.getId());
    }

    /**
     * 查看是否有系统新消息
     *
     */
    @GetMapping("/new/inform")
    public NewInformDTO getNewInform() {
        return informService.getNewInform(SessionContextHolder.getId());
    }
}
